@@ -1,4 +1,4 @@
-# @(#)$Id: Bob.pm 321 2011-11-30 00:01:49Z pjf $
+# @(#)$Id: Bob.pm 325 2011-12-02 04:35:54Z pjf $
 
 package Bob;
 
@@ -14,7 +14,7 @@ BEGIN {
    $ENV{PATH}   =~ m{ \A /home/sand }mx and whimper 'Stopped Konig';
 }
 
-use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 321 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 325 $ =~ /\d+/gmx );
 
 use File::Spec::Functions;
 use Module::Build;
@@ -25,8 +25,17 @@ sub new {
    my $module     = $params->{module} or whimper 'No module name';
    my $distname   = $module; $distname =~ s{ :: }{-}gmx;
    my $class_path = catfile( q(lib), split m{ :: }mx, $module.q(.pm) );
+   my $sub_class  = Module::Build->subclass( code => q{
+      sub ACTION_distmeta {
+         my $self = shift; use Pod::Select;
 
-   return Module::Build->new
+         $self->notes->{create_readme_pod} and podselect( {
+            -output => q(README.pod) }, $self->dist_version_from );
+
+         return $self->SUPER::ACTION_distmeta;
+      } }, );
+
+   return $sub_class->new
       ( add_to_cleanup     => [ q(Debian_CPANTS.txt), $distname.q(-*),
                                 map { ( q(*/) x $_ ).q(*~) } 0..5 ],
         build_requires     => $params->{build_requires},
@@ -59,6 +68,7 @@ sub __get_no_index {
 sub __get_notes {
    my $params = shift; my $notes = $params->{notes} || {};
 
+   $notes->{create_readme_pod} = $params->{create_readme_pod} || 0;
    $notes->{stop_tests} = ($params->{stop_tests} || 0) && __cpan_testing()
                         ? 'CPAN Testing stopped' : 0;
 
